NAME

Git::MoreHooks::ScanCtags - GitHooks plugin to create or update ctags after commit or merge

VERSION

version 0.019

SYNOPSIS

As a Git::Hooks plugin you don't use this Perl module directly. Instead, you may configure it in a Git configuration file like this:

[githooks]

  # Enable the plugin
  plugin = Git::MoreHooks::ScanCtags

[githooks "scanctags"]
  # Default values underneath:

  # Outfile (tags) name
  tags = tags

  # Directories to scan
  dir = lib
  dir = bin
  dir = t

  # File types (by suffix) to scan (in above dirs)
  suffix = pm
  suffix = pl
  suffix = t

  # Scan all executable files (in above dirs)
  executable = 1

  # verbose
  verbose = 1

DESCRIPTION

This Git::Hooks plugin hooks itself to the hooks below to perform post-commit and post-merge actions.

  • post-commit, post-applypatch, post-checkout, post-merge

Keep tags file updated and in sync with committed code.

To enable this plugin you should add it to the githooks.plugin configuration option:

[githooks]
  plugin = Git::MoreHooks::ScanCtags

NAME

Git::MoreHooks::CreateTags - Git::Hooks plugin to create or update tags file

CONFIGURATION

The plugin is configured by the following git options under the githooks.scanctags subsection.

It can be disabled for specific references via the githooks.ref and githooks.noref options about which you can read in the Git::Hooks documentation.

dir

Directories to scan.

suffix

Scan files with these file endings in the directories above.

executable BOOL, default: 1

Scan every executable file for tags in the directories above.

verbose BOOL, default: 1

Turn on or off verbose reporting. Set this option to 0 if you don't want the hook to report "Discovered total %s tags in %s files. Written to file '%s'."

REFERENCES

  • Perl::Tags

    Module used to scan Perl files for tags.

AUTHOR

'Mikko Koivunalho <mikkoi@cpan.org>'

COPYRIGHT AND LICENSE

This software is copyright (c) 2022 by Mikko Koivunalho.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.