NAME
Git::Libgit2::Error - Wraps git_error_last() into a Perl structure
VERSION
version 0.001
SYNOPSIS
my $rc = git_repository_open(\my $repo, $path);
if ($rc < 0) {
die Git::Libgit2::Error->last($rc); # stringifies
}
DESCRIPTION
Plain object with code, klass, message. Stringifies via overload. Used by Git::Native to construct typed exceptions.
SUPPORT
Issues
Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-git-libgit2/issues.
CONTRIBUTING
Contributions are welcome! Please fork the repository and submit a pull request.
AUTHOR
Torsten Raudssus <getty@cpan.org>
COPYRIGHT AND LICENSE
This software is copyright (c) 2026 by Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.