NAME
Git::Libgit2::FFI - Internal FFI::Platypus instance for Git::Libgit2
VERSION
version 0.001
SYNOPSIS
use Git::Libgit2::FFI;
my $ffi = Git::Libgit2::FFI::ffi();
DESCRIPTION
Internal use only. Holds the singleton FFI::Platypus instance with all attached libgit2 functions. Consumers should use Git::Libgit2 instead.
SUPPORT
Issues
Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-git-libgit2/issues.
CONTRIBUTING
Contributions are welcome! Please fork the repository and submit a pull request.
AUTHOR
Torsten Raudssus <getty@cpan.org>
COPYRIGHT AND LICENSE
This software is copyright (c) 2026 by Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.